BorderRadius

Struct BorderRadius 

pub struct BorderRadius {
    pub top_left: f32,
    pub top_right: f32,
    pub bottom_left: f32,
    pub bottom_right: f32,
}

Fields

top_left: f32top_right: f32bottom_left: f32bottom_right: f32

Implementations

Source

impl BorderRadius

pub const ZERO: Self

pub fn new( top_left: f32, top_right: f32, bottom_left: f32, bottom_right: f32, ) -> Self

Creates a BorderRadius with individual values for each corner

pub fn all(radius: f32) -> Self

Creates a BorderRadius with the same radius for all corners

pub fn vertical(top: f32, bottom: f32) -> Self

Creates a BorderRadius with the same radius for top and bottom

pub fn horizontal(left: f32, right: f32) -> Self

Creates a BorderRadius with the same radius for left and right

pub fn top(radius: f32) -> Self

Creates a BorderRadius with radius only on top corners

pub fn bottom(radius: f32) -> Self

Creates a BorderRadius with radius only on bottom corners

pub fn left(radius: f32) -> Self

Creates a BorderRadius with radius only on left corners

pub fn right(radius: f32) -> Self

Creates a BorderRadius with radius only on right corners